@@ -29,25 +29,23 @@
 #include "as-xml.h"
 #include "as-yaml.h"
 
-G_BEGIN_DECLS
-#pragma GCC visibility push(hidden)
+AS_BEGIN_PRIVATE_DECLS
 
-AsContext	      *as_agreement_get_context (AsAgreement *agreement);
-void		       as_agreement_set_context (AsAgreement *agreement, AsContext *context);
+AsContext *as_agreement_get_context (AsAgreement *agreement);
+void	   as_agreement_set_context (AsAgreement *agreement, AsContext *context);
 
-void	 as_agreement_to_xml_node (AsAgreement *agreement, AsContext *ctx, xmlNode *root);
-gboolean as_agreement_load_from_xml (AsAgreement *agreement,
-				     AsContext	 *ctx,
-				     xmlNode	 *node,
-				     GError	**error);
+void	   as_agreement_to_xml_node (AsAgreement *agreement, AsContext *ctx, xmlNode *root);
+gboolean   as_agreement_load_from_xml (AsAgreement *agreement,
+				       AsContext   *ctx,
+				       xmlNode	   *node,
+				       GError	  **error);
 
-gboolean as_agreement_load_from_yaml (AsAgreement    *agreement,
-				      AsContext	     *ctx,
-				      struct fy_node *node,
-				      GError	    **error);
+gboolean   as_agreement_load_from_yaml (AsAgreement    *agreement,
+					AsContext      *ctx,
+					struct fy_node *node,
+					GError	      **error);
 void as_agreement_emit_yaml (AsAgreement *agreement, AsContext *ctx, struct fy_emitter *emitter);
 
-#pragma GCC visibility pop
-G_END_DECLS
+AS_END_PRIVATE_DECLS
 
 #endif /* __AS_AGREEMENT_PRIVATE_H */
