@@ -25,8 +25,7 @@
 #include "as-xml.h"
 #include "as-yaml.h"
 
-G_BEGIN_DECLS
-#pragma GCC visibility push(hidden)
+AS_BEGIN_PRIVATE_DECLS
 
 gboolean as_issue_load_from_xml (AsIssue *issue, AsContext *ctx, xmlNode *node, GError **error);
 void	 as_issue_to_xml_node (AsIssue *issue, AsContext *ctx, xmlNode *root);
@@ -37,7 +36,6 @@ gboolean as_issue_load_from_yaml (AsIssue	 *issue,
 				  GError	**error);
 void	 as_issue_emit_yaml (AsIssue *issue, AsContext *ctx, struct fy_emitter *emitter);
 
-#pragma GCC visibility pop
-G_END_DECLS
+AS_END_PRIVATE_DECLS
 
 #endif /* __AS_ISSUE_PRIVATE_H */
