@@ -28,13 +28,17 @@
 G_BEGIN_DECLS
 #pragma GCC visibility push(hidden)
 
+/* clang-format off */
 #define AS_BEGIN_PRIVATE_DECLS \
 	G_BEGIN_DECLS          \
 	_Pragma ("GCC visibility push(hidden)")
 
-#define AS_END_PRIVATE_DECLS _Pragma ("GCC visibility pop") G_END_DECLS
+#define AS_END_PRIVATE_DECLS \
+	_Pragma ("GCC visibility pop") \
+	G_END_DECLS
 
 #define AS_INTERNAL_VISIBLE __attribute__((visibility("default")))
+/* clang-format on */
 
 /**
  * AS_UNIQ:
