@@ -25,22 +25,20 @@
 #include "as-xml.h"
 #include "as-yaml.h"
 
-G_BEGIN_DECLS
-#pragma GCC visibility push(hidden)
+AS_BEGIN_PRIVATE_DECLS
 
-gboolean	       as_suggested_load_from_xml (AsSuggested *suggested,
-						   AsContext   *ctx,
-						   xmlNode     *node,
-						   GError     **error);
+gboolean as_suggested_load_from_xml (AsSuggested *suggested,
+				     AsContext	 *ctx,
+				     xmlNode	 *node,
+				     GError	**error);
 void	 as_suggested_to_xml_node (AsSuggested *suggested, AsContext *ctx, xmlNode *root);
 
-gboolean as_suggested_load_from_yaml (AsSuggested *suggested,
-				      AsContext	  *ctx,
-				      GNode	  *node,
-				      GError	 **error);
-void	 as_suggested_emit_yaml (AsSuggested *suggested, AsContext *ctx, yaml_emitter_t *emitter);
+gboolean as_suggested_load_from_yaml (AsSuggested    *suggested,
+				      AsContext	     *ctx,
+				      struct fy_node *node,
+				      GError	    **error);
+void as_suggested_emit_yaml (AsSuggested *suggested, AsContext *ctx, struct fy_emitter *emitter);
 
-#pragma GCC visibility pop
-G_END_DECLS
+AS_END_PRIVATE_DECLS
 
 #endif /* __AS_SUGGESTED_PRIVATE_H */
