@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2024 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -18,7 +18,7 @@
  * along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__APPSTREAM_H) && !defined (AS_COMPILATION)
+#if !defined(__APPSTREAM_H) && !defined(AS_COMPILATION)
 #error "Only <appstream.h> can be included directly."
 #endif
 
@@ -32,16 +32,15 @@ G_BEGIN_DECLS
 #define AS_TYPE_TRANSLATION (as_translation_get_type ())
 G_DECLARE_DERIVABLE_TYPE (AsTranslation, as_translation, AS, TRANSLATION, GObject)
 
-struct _AsTranslationClass
-{
-	GObjectClass		parent_class;
+struct _AsTranslationClass {
+	GObjectClass parent_class;
 	/*< private >*/
-	void (*_as_reserved1)	(void);
-	void (*_as_reserved2)	(void);
-	void (*_as_reserved3)	(void);
-	void (*_as_reserved4)	(void);
-	void (*_as_reserved5)	(void);
-	void (*_as_reserved6)	(void);
+	void (*_as_reserved1) (void);
+	void (*_as_reserved2) (void);
+	void (*_as_reserved3) (void);
+	void (*_as_reserved4) (void);
+	void (*_as_reserved5) (void);
+	void (*_as_reserved6) (void);
 };
 
 /**
@@ -60,22 +59,19 @@ typedef enum {
 	AS_TRANSLATION_KIND_LAST
 } AsTranslationKind;
 
-const gchar		*as_translation_kind_to_string (AsTranslationKind kind);
-AsTranslationKind	as_translation_kind_from_string (const gchar *kind_str);
+const gchar	 *as_translation_kind_to_string (AsTranslationKind kind);
+AsTranslationKind as_translation_kind_from_string (const gchar *kind_str);
 
-AsTranslation		*as_translation_new (void);
+AsTranslation	 *as_translation_new (void);
 
-AsTranslationKind	as_translation_get_kind (AsTranslation *tr);
-void			as_translation_set_kind (AsTranslation *tr,
-						AsTranslationKind kind);
+AsTranslationKind as_translation_get_kind (AsTranslation *tr);
+void		  as_translation_set_kind (AsTranslation *tr, AsTranslationKind kind);
 
-const gchar		*as_translation_get_id (AsTranslation *tr);
-void			as_translation_set_id (AsTranslation *tr,
-					       const gchar *id);
+const gchar	 *as_translation_get_id (AsTranslation *tr);
+void		  as_translation_set_id (AsTranslation *tr, const gchar *id);
 
-const gchar		*as_translation_get_source_locale (AsTranslation *tr);
-void			as_translation_set_source_locale (AsTranslation *tr,
-							  const gchar   *locale);
+const gchar	 *as_translation_get_source_locale (AsTranslation *tr);
+void		  as_translation_set_source_locale (AsTranslation *tr, const gchar *locale);
 
 G_END_DECLS
 
