@@ -26,6 +26,7 @@ dnf --assumeyes --quiet --setopt=install_weak_deps=False install \
     gcovr \
     xz-devel \
     libuuid-devel \
+    'pkgconfig(bash-completion)' \
     'pkgconfig(gio-2.0)' \
     'pkgconfig(gobject-introspection-1.0)' \
     'pkgconfig(xmlb)' \
@@ -41,7 +42,6 @@ dnf --assumeyes --quiet --setopt=install_weak_deps=False install \
     'pkgconfig(gdk-pixbuf-2.0)' \
     'pkgconfig(pango)' \
     'pkgconfig(Qt6Core)' \
-    qt6-linguist \
     sed \
     vala \
     xmlto
